Documentation
¶
Index ¶
- func AddInspectTool(mcpServer *server.MCPServer)
- func AddRenameTool(mcpServer *server.MCPServer)
- func Inspect(path string, lineNumber int, symbolName string, includePrivate bool, ...) (string, error)
- func NewMCPServer(config *ServerConfig) *server.MCPServer
- func Rename(filePath string, lineNumber int, symbolName string, newName string) (string, error)
- func ServeHTTP(mcpServer *server.MCPServer, host string, port string) error
- func ServeStdio(mcpServer *server.MCPServer) error
- type ServerConfig
- type Transport
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddInspectTool ¶
func AddRenameTool ¶
func Inspect ¶
func Inspect( path string, lineNumber int, symbolName string, includePrivate bool, workspaceDir string, ) (string, error)
Inspect analyzes a Go symbol (package, file, function, type, etc.) path can be a directory path, file path, or import statement path lineNumber and symbolName are optional for file paths to specify a particular symbol includePrivate determines whether private symbols are included workspaceDir is the working directory for package resolution and reference finding, and is required.
func NewMCPServer ¶
func NewMCPServer(config *ServerConfig) *server.MCPServer
NewMCPServer creates a new MCP server with the specified configuration
func ServeStdio ¶
ServeStdio starts the MCP server on stdio transport
Types ¶
type ServerConfig ¶
ServerConfig holds configuration for the MCP server
func DefaultServerConfig ¶
func DefaultServerConfig() *ServerConfig
DefaultServerConfig returns a default server configuration
Click to show internal directories.
Click to hide internal directories.